GpuQuerySet class abstract interface

A set of GPU queries.

See WebGPU spec: GPUQuerySet.

Implemented types

Properties

count int
The number of queries in this set.
no setter
hashCode int
The hash code for this object.
no setterinherited
label String
A human-readable label for debugging.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type GpuQueryType
The type of queries in this set.
no setter

Methods

destroy() → void
Destroys the query set.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited